@@ -73,11 +73,21 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-S3ReferenceTypeDef = TypedDict(
-    "S3ReferenceTypeDef",
+_RequiredS3ReferenceTypeDef = TypedDict(
+    "_RequiredS3ReferenceTypeDef",
     {
         "bucket": str,
         "key": str,
-        "objectVersion": NotRequired[str],
     },
 )
+_OptionalS3ReferenceTypeDef = TypedDict(
+    "_OptionalS3ReferenceTypeDef",
+    {
+        "objectVersion": str,
+    },
+    total=False,
+)
+
+
+class S3ReferenceTypeDef(_RequiredS3ReferenceTypeDef, _OptionalS3ReferenceTypeDef):
+    pass
